This forum has been archived. All content is frozen. Please use KDE Discuss instead.

Typo Patch

Tags: None
(comma "," separated)
icwiener
Moderator
Posts
50
Karma
0
OS

Typo Patch

Sat Oct 13, 2007 7:57 pm
Hi,

I found some typos while translating:
- then -> than
- don't -> do not
- several others

They are in comments sometimes but wrong is wrong. :)

cheers

If you have problems getting the patch from the post, I'm on #freenode with the same name.

The diff is against the trunk version.
Code: Select all
Index: libktorrent/dht/kclosestnodessearch.cpp
===================================================================
--- libktorrent/dht/kclosestnodessearch.cpp     (revision 724887)
+++ libktorrent/dht/kclosestnodessearch.cpp     (working copy)
@@ -56,7 +56,7 @@
                        const dht::Key & max = emap.rbegin()->first;
                        if (d < max)
                        {
-                               // insert if d is smaller then max
+                               // insert if d is smaller than max
                                emap.insert(std::make_pair(d,e));
                                // erase the old max value
                                emap.erase(max);
Index: libktorrent/dht/database.h
===================================================================
--- libktorrent/dht/database.h  (revision 724887)
+++ libktorrent/dht/database.h  (working copy)
@@ -84,7 +84,7 @@
                 * Get max_entries items from the database, which have
                 * the same key, items are taken randomly from the list.
                 * If the key is not present no items will be returned, if
-                * there are fewer then max_entries items for the key, all
+                * there are fewer than max_entries items for the key, all
                 * entries will be returned
                 * @param key The key to search for
                 * @param dbl The list to store the items in
@@ -93,7 +93,7 @@
                void sample(const dht::Key & key,DBItemList & dbl,bt::Uint32 max_entries);

                /**
-                * Expire all items older then 30 minutes
+                * Expire all items older than 30 minutes
                 * @param now The time it is now
                 * (we pass this along so we only have to calculate it once)
                 */
Index: libktorrent/dht/dht.cpp
===================================================================
--- libktorrent/dht/dht.cpp     (revision 724887)
+++ libktorrent/dht/dht.cpp     (working copy)
@@ -240,7 +240,7 @@

        bool DHT::canStartTask() const
        {
-               // we can start a task if we have less then  7 runnning and
+               // we can start a task if we have less than 7 runnning and
                // there are at least 16 RPC slots available
                if (tman->getNumTasks() >= 7)
                        return false;
Index: libktorrent/dht/key.h
===================================================================
--- libktorrent/dht/key.h       (revision 724887)
+++ libktorrent/dht/key.h       (working copy)
@@ -86,32 +86,32 @@
                bool operator != (const Key & other) const;

                /**
-                * Smaller then operator.
+                * Smaller than operator.
                 * @param other The key to compare
-                * @return rue if this key is smaller then other
+                * @return true if this key is smaller than other
                 */
                bool operator < (const Key & other) const;


                /**
-                * Smaller then or equal operator.
+                * Smaller than or equal operator.
                 * @param other The key to compare
-                * @return rue if this key is smaller then or equal to other
+                * @return true if this key is smaller than or equal to other
                 */
                bool operator <= (const Key & other) const;


                /**
-                * Greater then operator.
+                * Greater than operator.
                 * @param other The key to compare
-                * @return rue if this key is greater then other
+                * @return true if this key is greater than other
                 */
                bool operator > (const Key & other) const;

                /**
-                * Greater then or equal operator.
+                * Greater than or equal operator.
                 * @param other The key to compare
-                * @return rue if this key is greater then or equal to other
+                * @return true if this key is greater than or equal to other
                 */
                bool operator >= (const Key & other) const;

Index: libktorrent/diskio/chunkmanager.cpp
===================================================================
--- libktorrent/diskio/chunkmanager.cpp (revision 724887)
+++ libktorrent/diskio/chunkmanager.cpp (working copy)
@@ -913,7 +913,7 @@
                        if (reprioritise_border_chunk)
                                prioritise(last+1,last+1,maxp);

-                       // last smaller then first is not normal, so just return
+                       // last smaller than first is not normal, so just return
                        if (last < first)
                        {
                                cache->downloadStatusChanged(tf,download);
@@ -989,7 +989,7 @@
                        }
                }

-               // last smaller then first is not normal, so just return
+               // last smaller than first is not normal, so just return
                if (last < first)
                {
                        return;
Index: libktorrent/interfaces/piecedownloader.h
===================================================================
--- libktorrent/interfaces/piecedownloader.h    (revision 724887)
+++ libktorrent/interfaces/piecedownloader.h    (working copy)
@@ -134,7 +134,7 @@
                void downloaded(const bt::Piece & p);

                /**
-                * Emitted when a request takes longer then 60 seconds to download.
+                * Emitted when a request takes longer than 60 seconds to download.
                 * The sender of the request will have to request it again. This does not apply for
                 * unsent requests. Their timestamps will be updated when they get transmitted.
                 * @param r The request
Index: libktorrent/interfaces/torrentinterface.h
===================================================================
--- libktorrent/interfaces/torrentinterface.h   (revision 724887)
+++ libktorrent/interfaces/torrentinterface.h   (working copy)
@@ -451,7 +451,7 @@
                void maxRatioChanged(kt::TorrentInterface* me);

                /**
-                * Emited then torrent is stopped from seeding by KTorrent.
+                * Emited when torrent is stopped from seeding by KTorrent.
                 * Happens when torrent has reached maximum share ratio and maybe we'll add something more...
                 * @param me The object which emitted the signal.
                 * @param reason The reason why it was aut stopped
Index: libktorrent/mse/encryptedauthenticate.cpp
===================================================================
--- libktorrent/mse/encryptedauthenticate.cpp   (revision 724887)
+++ libktorrent/mse/encryptedauthenticate.cpp   (working copy)
@@ -233,12 +233,12 @@

                // noz we wait for the normal handshake
                state = NORMAL_HANDSHAKE;
-               // if we have read more then the crypto handshake, reinsert it
+               // if we have read more than the crypto handshake, reinsert it
                if (buf_size > vc_off + 14 + pad_D_len)
                {
                        Uint32 off = vc_off + 14 + pad_D_len;
                        sock->reinsert(buf + off,buf_size - off);
-                       Authenticate::onReadyRead();
+                       Authanticate::onReadyRead();
                }
        }

Index: libktorrent/peer/peermanager.cpp
===================================================================
--- libktorrent/peer/peermanager.cpp    (revision 724887)
+++ libktorrent/peer/peermanager.cpp    (working copy)
@@ -107,7 +107,7 @@
                connectToPeers();
        }

-       void PeerManager::killChokedPeers(Uint32 older_then)
+       void PeerManager::killChokedPeers(Uint32 older_than)
        {
                Out() << "Getting rid of peers which have been choked for a long time" << endl;
                TimeStamp now = bt::GetCurrentTime();
@@ -116,7 +116,7 @@
                while (i != peer_list.end() && num_killed < 20)
                {
                        Peer* p = *i;
-                       if (p->isChoked() && (now - p->getChokeTime()) > older_then)
+                       if (p->isChoked() && (now - p->getChokeTime()) > older_than)
                        {
                                p->kill();
                                num_killed++;
Index: libktorrent/torrent/torrentcontrol.cpp
===================================================================
--- libktorrent/torrent/torrentcontrol.cpp      (revision 724887)
+++ libktorrent/torrent/torrentcontrol.cpp      (working copy)
@@ -256,7 +256,7 @@
                        if (stats.download_rate > 0)
                                stalled_timer.update();

-                       // do a manual update if we are stalled for more then 2 minutes
+                       // do a manual update if we are stalled for more than 2 minutes
                        // we do not do this for private torrents
                        if (stalled_timer.getElapsedSinceUpdate() > 120000 && !stats.completed &&
                                !stats.priv_torrent)
Index: libktorrent/torrent/queuemanager.cpp
===================================================================
--- libktorrent/torrent/queuemanager.cpp        (revision 724887)
+++ libktorrent/torrent/queuemanager.cpp        (working copy)
@@ -124,7 +124,7 @@
                                                        return kt::NOT_ENOUGH_DISKSPACE;

                                                case 1: //ask user
-                                                       if (KMessageBox::questionYesNo(0, i18n("You don't have enough disk space to download this torrent. Are you sure you want to continue?"), i18n("Insufficient disk space for %1",s.torrent_name)) == KMessageBox::No)
+                                                       if (KMessageBox::questionYesNo(0, i18n("You do not have enough disk space to download this torrent. Are you sure you want to continue?"), i18n("Insufficient disk space for %1",s.torrent_name)) == KMessageBox::No)
                                                        {
                                                                tc->setPriority(0);
                                                                return kt::USER_CANCELED;
Index: libktorrent/labelview.h
===================================================================
--- libktorrent/labelview.h     (revision 724887)
+++ libktorrent/labelview.h     (working copy)
@@ -57,7 +57,7 @@
                /// Can be reimplemented to update the GUI of the item by base classes
                virtual void update() {}

-               /// smaller then operator for sorting purposes, by default it sorts by title
+               /// smaller than operator for sorting purposes, by default it sorts by title
                virtual bool operator < (const LabelViewItem & item);

        private:
Index: libktorrent/download/chunkdownload.cpp
===================================================================
--- libktorrent/download/chunkdownload.cpp      (revision 724887)
+++ libktorrent/download/chunkdownload.cpp      (working copy)
@@ -461,7 +461,7 @@

        bool ChunkDownload::usingContinuousHashing() const
        {
-               // if the pieces are larger then 1 MB we will be using the continuous hashing feature
+               // if the pieces are larger than 1 MB we will be using the continuous hashing feature
                return pieces.getNumBits() > 64;
        }
 }
Index: libktorrent/util/sha1hash.h
===================================================================
--- libktorrent/util/sha1hash.h (revision 724887)
+++ libktorrent/util/sha1hash.h (working copy)
@@ -134,7 +134,7 @@
                 * Function to compare 2 hashes
                 * @param a The first hash
                 * @param h The second hash
-                * @return wether a is smaller then b
+                * @return wether a is smaller than b
                 */
                friend bool operator < (const SHA1Hash & a,const SHA1Hash & b);

Index: libktorrent/util/log.cpp
===================================================================
--- libktorrent/util/log.cpp    (revision 724887)
+++ libktorrent/util/log.cpp    (working copy)
@@ -153,7 +153,7 @@
                        finishLine();
                        if (fptr->size() > MAX_LOG_FILE_SIZE && !rotate_job)
                        {
-                               tmp = "Log larger then 10 MB, rotating";
+                               tmp = "Log larger than 10 MB, rotating";
                                finishLine();
                                QString file = fptr->fileName();
                                fptr->close(); // close the log file
Index: ktorrent/advancedpref.ui
===================================================================
--- ktorrent/advancedpref.ui    (revision 724887)
+++ ktorrent/advancedpref.ui    (working copy)
@@ -162,10 +162,10 @@
            <string>&lt;html>&lt;head>&lt;meta name="qrichtext" content="1" />&lt;style type="text/css">
 p, li { white-space: pre-wrap; }
 &lt;/style>&lt;/head>&lt;body style=" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;">
-&lt;p style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;">Because rechecking big chunks can take a lot of time, the recheck can be disabled when the chunks are bigger then a certain size.&lt;/p>&lt;/body>&lt;/html></string>
+&lt;p style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;">Because rechecking big chunks can take a lot of time, the recheck can be disabled when the chunks are bigger than a certain size.&lt;/p>&lt;/body>&lt;/html></string>
           </property>
           <property name="text" >
-           <string>Don't recheck when chunks are bigger then</string>
+           <string>Do not recheck when chunks are bigger than</string>
           </property>
          </widget>
         </item>
@@ -386,7 +386,7 @@
          <string>&lt;html>&lt;head>&lt;meta name="qrichtext" content="1" />&lt;style type="text/css">
 p, li { white-space: pre-wrap; }
 &lt;/style>&lt;/head>&lt;body style=" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;">
-&lt;p style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;">Instead of doing a quick reservation, do a full reservation. This is slower then the quick way, but avoids fragmentation on the disk.&lt;/p>&lt;/body>&lt;/html></string>
+&lt;p style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;">Instead of doing a quick reservation, do a full reservation. This is slower than the quick way, but avoids fragmentation on the disk.&lt;/p>&lt;/body>&lt;/html></string>
         </property>
         <property name="text" >
          <string>Fully reserve diskspace (avoids fragmentation)</string>
@@ -418,7 +418,7 @@
 &lt;p style="-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;">&lt;/p>
 &lt;p style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;">&lt;span style=" font-weight:600;">Basic: &lt;/span>Will work on all filesystems, but is slow.&lt;/p>
 &lt;p style="-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;">&lt;/p>
-&lt;p style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;">&lt;span style=" font-weight:600;">Filesystem Specific: &lt;/span>Will use special methods provided by some filesystems, which are faster then the basic method.&lt;/p>&lt;/body>&lt;/html></string>
+&lt;p style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;">&lt;span style=" font-weight:600;">Filesystem Specific: &lt;/span>Will use special methods provided by some filesystems, which are faster than the basic method.&lt;/p>&lt;/body>&lt;/html></string>
           </property>
           <item>
            <property name="text" >
Index: ktorrent/globalpref.ui
===================================================================
--- ktorrent/globalpref.ui      (revision 724887)
+++ ktorrent/globalpref.ui      (working copy)
@@ -341,7 +341,7 @@
         </property>
         <item>
          <property name="text" >
-          <string>Don't start torrents</string>
+          <string>Do not start torrents</string>
          </property>
         </item>
         <item>
icwiener
Moderator
Posts
50
Karma
0
OS

Sun Oct 28, 2007 3:59 pm
*push*

I hope it is ok to push this...
buddabrod
Registered Member
Posts
21
Karma
0

Mon Oct 29, 2007 2:24 pm
Really ugly typos... i hope this patch will be included very soon :P
George
Moderator
Posts
5421
Karma
1

Mon Oct 29, 2007 7:09 pm
Send it by e-mail to me as an attached file, because patches copy pasted from a website or forum tend to not apply very well.
icwiener
Moderator
Posts
50
Karma
0
OS

Mon Oct 29, 2007 7:15 pm
Woops. I just saw a mistake I made.

Here's the new diff:

Code: Select all
Index: libktorrent/dht/kclosestnodessearch.cpp
===================================================================
--- libktorrent/dht/kclosestnodessearch.cpp     (revision 724887)
+++ libktorrent/dht/kclosestnodessearch.cpp     (working copy)
@@ -56,7 +56,7 @@
                        const dht::Key & max = emap.rbegin()->first;
                        if (d < max)
                        {
-                               // insert if d is smaller then max
+                               // insert if d is smaller than max
                                emap.insert(std::make_pair(d,e));
                                // erase the old max value
                                emap.erase(max);
Index: libktorrent/dht/database.h
===================================================================
--- libktorrent/dht/database.h  (revision 724887)
+++ libktorrent/dht/database.h  (working copy)
@@ -84,7 +84,7 @@
                 * Get max_entries items from the database, which have
                 * the same key, items are taken randomly from the list.
                 * If the key is not present no items will be returned, if
-                * there are fewer then max_entries items for the key, all
+                * there are fewer than max_entries items for the key, all
                 * entries will be returned
                 * @param key The key to search for
                 * @param dbl The list to store the items in
@@ -93,7 +93,7 @@
                void sample(const dht::Key & key,DBItemList & dbl,bt::Uint32 max_entries);

                /**
-                * Expire all items older then 30 minutes
+                * Expire all items older than 30 minutes
                 * @param now The time it is now
                 * (we pass this along so we only have to calculate it once)
                 */
Index: libktorrent/dht/dht.cpp
===================================================================
--- libktorrent/dht/dht.cpp     (revision 724887)
+++ libktorrent/dht/dht.cpp     (working copy)
@@ -240,7 +240,7 @@

        bool DHT::canStartTask() const
        {
-               // we can start a task if we have less then  7 runnning and
+               // we can start a task if we have less than 7 runnning and
                // there are at least 16 RPC slots available
                if (tman->getNumTasks() >= 7)
                        return false;
Index: libktorrent/dht/key.h
===================================================================
--- libktorrent/dht/key.h       (revision 724887)
+++ libktorrent/dht/key.h       (working copy)
@@ -86,32 +86,32 @@
                bool operator != (const Key & other) const;

                /**
-                * Smaller then operator.
+                * Smaller than operator.
                 * @param other The key to compare
-                * @return rue if this key is smaller then other
+                * @return true if this key is smaller than other
                 */
                bool operator < (const Key & other) const;


                /**
-                * Smaller then or equal operator.
+                * Smaller than or equal operator.
                 * @param other The key to compare
-                * @return rue if this key is smaller then or equal to other
+                * @return true if this key is smaller than or equal to other
                 */
                bool operator <= (const Key & other) const;


                /**
-                * Greater then operator.
+                * Greater than operator.
                 * @param other The key to compare
-                * @return rue if this key is greater then other
+                * @return true if this key is greater than other
                 */
                bool operator > (const Key & other) const;

                /**
-                * Greater then or equal operator.
+                * Greater than or equal operator.
                 * @param other The key to compare
-                * @return rue if this key is greater then or equal to other
+                * @return true if this key is greater than or equal to other
                 */
                bool operator >= (const Key & other) const;

Index: libktorrent/diskio/chunkmanager.cpp
===================================================================
--- libktorrent/diskio/chunkmanager.cpp (revision 724887)
+++ libktorrent/diskio/chunkmanager.cpp (working copy)
@@ -913,7 +913,7 @@
                        if (reprioritise_border_chunk)
                                prioritise(last+1,last+1,maxp);

-                       // last smaller then first is not normal, so just return
+                       // last smaller than first is not normal, so just return
                        if (last < first)
                        {
                                cache->downloadStatusChanged(tf,download);
@@ -989,7 +989,7 @@
                        }
                }

-               // last smaller then first is not normal, so just return
+               // last smaller than first is not normal, so just return
                if (last < first)
                {
                        return;
Index: libktorrent/interfaces/piecedownloader.h
===================================================================
--- libktorrent/interfaces/piecedownloader.h    (revision 724887)
+++ libktorrent/interfaces/piecedownloader.h    (working copy)
@@ -134,7 +134,7 @@
                void downloaded(const bt::Piece & p);

                /**
-                * Emitted when a request takes longer then 60 seconds to download.
+                * Emitted when a request takes longer than 60 seconds to download.
                 * The sender of the request will have to request it again. This does not apply for
                 * unsent requests. Their timestamps will be updated when they get transmitted.
                 * @param r The request
Index: libktorrent/interfaces/torrentinterface.h
===================================================================
--- libktorrent/interfaces/torrentinterface.h   (revision 724887)
+++ libktorrent/interfaces/torrentinterface.h   (working copy)
@@ -451,7 +451,7 @@
                void maxRatioChanged(kt::TorrentInterface* me);

                /**
-                * Emited then torrent is stopped from seeding by KTorrent.
+                * Emited when torrent is stopped from seeding by KTorrent.
                 * Happens when torrent has reached maximum share ratio and maybe we'll add something more...
                 * @param me The object which emitted the signal.
                 * @param reason The reason why it was aut stopped
Index: libktorrent/mse/encryptedauthenticate.cpp
===================================================================
--- libktorrent/mse/encryptedauthenticate.cpp   (revision 724887)
+++ libktorrent/mse/encryptedauthenticate.cpp   (working copy)
@@ -233,7 +233,7 @@

                // noz we wait for the normal handshake
                state = NORMAL_HANDSHAKE;
-               // if we have read more then the crypto handshake, reinsert it
+               // if we have read more than the crypto handshake, reinsert it
                if (buf_size > vc_off + 14 + pad_D_len)
                {
                        Uint32 off = vc_off + 14 + pad_D_len;
Index: libktorrent/peer/peermanager.cpp
===================================================================
--- libktorrent/peer/peermanager.cpp    (revision 724887)
+++ libktorrent/peer/peermanager.cpp    (working copy)
@@ -107,7 +107,7 @@
                connectToPeers();
        }

-       void PeerManager::killChokedPeers(Uint32 older_then)
+       void PeerManager::killChokedPeers(Uint32 older_than)
        {
                Out() << "Getting rid of peers which have been choked for a long time" << endl;
                TimeStamp now = bt::GetCurrentTime();
@@ -116,7 +116,7 @@
                while (i != peer_list.end() && num_killed < 20)
                {
                        Peer* p = *i;
-                       if (p->isChoked() && (now - p->getChokeTime()) > older_then)
+                       if (p->isChoked() && (now - p->getChokeTime()) > older_than)
                        {
                                p->kill();
                                num_killed++;
Index: libktorrent/torrent/torrentcontrol.cpp
===================================================================
--- libktorrent/torrent/torrentcontrol.cpp      (revision 724887)
+++ libktorrent/torrent/torrentcontrol.cpp      (working copy)
@@ -256,7 +256,7 @@
                        if (stats.download_rate > 0)
                                stalled_timer.update();

-                       // do a manual update if we are stalled for more then 2 minutes
+                       // do a manual update if we are stalled for more than 2 minutes
                        // we do not do this for private torrents
                        if (stalled_timer.getElapsedSinceUpdate() > 120000 && !stats.completed &&
                                !stats.priv_torrent)
Index: libktorrent/torrent/queuemanager.cpp
===================================================================
--- libktorrent/torrent/queuemanager.cpp        (revision 724887)
+++ libktorrent/torrent/queuemanager.cpp        (working copy)
@@ -124,7 +124,7 @@
                                                        return kt::NOT_ENOUGH_DISKSPACE;

                                                case 1: //ask user
-                                                       if (KMessageBox::questionYesNo(0, i18n("You don't have enough disk space to download this torrent. Are you sure you want to continue?"), i18n("Insufficient disk space for %1",s.torrent_name)) == KMessageBox::No)
+                                                       if (KMessageBox::questionYesNo(0, i18n("You do not have enough disk space to download this torrent. Are you sure you want to continue?"), i18n("Insufficient disk space for %1",s.torrent_name)) == KMessageBox::No)
                                                        {
                                                                tc->setPriority(0);
                                                                return kt::USER_CANCELED;
Index: libktorrent/labelview.h
===================================================================
--- libktorrent/labelview.h     (revision 724887)
+++ libktorrent/labelview.h     (working copy)
@@ -57,7 +57,7 @@
                /// Can be reimplemented to update the GUI of the item by base classes
                virtual void update() {}

-               /// smaller then operator for sorting purposes, by default it sorts by title
+               /// smaller than operator for sorting purposes, by default it sorts by title
                virtual bool operator < (const LabelViewItem & item);

        private:
Index: libktorrent/download/chunkdownload.cpp
===================================================================
--- libktorrent/download/chunkdownload.cpp      (revision 724887)
+++ libktorrent/download/chunkdownload.cpp      (working copy)
@@ -461,7 +461,7 @@

        bool ChunkDownload::usingContinuousHashing() const
        {
-               // if the pieces are larger then 1 MB we will be using the continuous hashing feature
+               // if the pieces are larger than 1 MB we will be using the continuous hashing feature
                return pieces.getNumBits() > 64;
        }
 }
Index: libktorrent/util/sha1hash.h
===================================================================
--- libktorrent/util/sha1hash.h (revision 724887)
+++ libktorrent/util/sha1hash.h (working copy)
@@ -134,7 +134,7 @@
                 * Function to compare 2 hashes
                 * @param a The first hash
                 * @param h The second hash
-                * @return wether a is smaller then b
+                * @return wether a is smaller than b
                 */
                friend bool operator < (const SHA1Hash & a,const SHA1Hash & b);

Index: libktorrent/util/log.cpp
===================================================================
--- libktorrent/util/log.cpp    (revision 724887)
+++ libktorrent/util/log.cpp    (working copy)
@@ -153,7 +153,7 @@
                        finishLine();
                        if (fptr->size() > MAX_LOG_FILE_SIZE && !rotate_job)
                        {
-                               tmp = "Log larger then 10 MB, rotating";
+                               tmp = "Log larger than 10 MB, rotating";
                                finishLine();
                                QString file = fptr->fileName();
                                fptr->close(); // close the log file
Index: ktorrent/advancedpref.ui
===================================================================
--- ktorrent/advancedpref.ui    (revision 724887)
+++ ktorrent/advancedpref.ui    (working copy)
@@ -162,10 +162,10 @@
            <string>&lt;html>&lt;head>&lt;meta name="qrichtext" content="1" />&lt;style type="text/css">
 p, li { white-space: pre-wrap; }
 &lt;/style>&lt;/head>&lt;body style=" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;">
-&lt;p style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;">Because rechecking big chunks can take a lot of time, the recheck can be disabled when the chunks are bigger then a certain size.&lt;/p>&lt;/body>&lt;/html></string>
+&lt;p style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;">Because rechecking big chunks can take a lot of time, the recheck can be disabled when the chunks are bigger than a certain size.&lt;/p>&lt;/body>&lt;/html></string>
           </property>
           <property name="text" >
-           <string>Don't recheck when chunks are bigger then</string>
+           <string>Do not recheck when chunks are bigger than</string>
           </property>
          </widget>
         </item>
@@ -386,7 +386,7 @@
          <string>&lt;html>&lt;head>&lt;meta name="qrichtext" content="1" />&lt;style type="text/css">
 p, li { white-space: pre-wrap; }
 &lt;/style>&lt;/head>&lt;body style=" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;">
-&lt;p style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;">Instead of doing a quick reservation, do a full reservation. This is slower then the quick way, but avoids fragmentation on the disk.&lt;/p>&lt;/body>&lt;/html></string>
+&lt;p style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;">Instead of doing a quick reservation, do a full reservation. This is slower than the quick way, but avoids fragmentation on the disk.&lt;/p>&lt;/body>&lt;/html></string>
         </property>
         <property name="text" >
          <string>Fully reserve diskspace (avoids fragmentation)</string>
@@ -418,7 +418,7 @@
 &lt;p style="-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;">&lt;/p>
 &lt;p style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;">&lt;span style=" font-weight:600;">Basic: &lt;/span>Will work on all filesystems, but is slow.&lt;/p>
 &lt;p style="-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;">&lt;/p>
-&lt;p style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;">&lt;span style=" font-weight:600;">Filesystem Specific: &lt;/span>Will use special methods provided by some filesystems, which are faster then the basic method.&lt;/p>&lt;/body>&lt;/html></string>
+&lt;p style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;">&lt;span style=" font-weight:600;">Filesystem Specific: &lt;/span>Will use special methods provided by some filesystems, which are faster than the basic method.&lt;/p>&lt;/body>&lt;/html></string>
           </property>
           <item>
            <property name="text" >
Index: ktorrent/globalpref.ui
===================================================================
--- ktorrent/globalpref.ui      (revision 724887)
+++ ktorrent/globalpref.ui      (working copy)
@@ -341,7 +341,7 @@
         </property>
         <item>
          <property name="text" >
-          <string>Don't start torrents</string>
+          <string>Do not start torrents</string>
          </property>
         </item>
         <item>
icwiener
Moderator
Posts
50
Karma
0
OS

Mon Oct 29, 2007 7:16 pm
George wrote:Send it by e-mail to me as an attached file, because patches copy pasted from a website or forum tend to not apply very well.


Ok, I'll try to find your email address. :)

/edit: done.

MfG

Last edited by icwiener on Mon Oct 29, 2007 7:18 pm, edited 1 time in total.
George
Moderator
Posts
5421
Karma
1

Mon Oct 29, 2007 7:17 pm
icwiener wrote:
George wrote:Send it by e-mail to me as an attached file, because patches copy pasted from a website or forum tend to not apply very well.


Ok, I'll try to find your email address. :)

MfG


joris DOT guisson AT gmail DOT com


Bookmarks



Who is online

Registered users: Bing [Bot], claydoh, Google [Bot], rblackwell
Index: libktorrent/peer/peermanager.h
===================================================================
--- libktorrent/peer/peermanager.h      (revision 724887)
+++ libktorrent/peer/peermanager.h      (working copy)
@@ -131,10 +131,10 @@
                void stop();

                /**
* Kill all peers who have been choked longer then @a older_then time.
* @param older_then Time in milliseconds
                 */
-               void killChokedPeers(Uint32 older_then);
+               void killChokedPeers(Uint32 older_than);

                Uint32 getNumConnectedPeers() const {return peer_list.count();}
                Uint32 getNumPending() const {return num_pending;}
@@ -131,10 +131,10 @@

                /**
-                * Kill all peers who have been choked longer then @a older_then time.
-                * @param older_then Time in milliseconds
+                * Kill all peers who have been choked longer than @a older_than time.
+                * @param older_than Time in milliseconds
                 */
Index: libktorrent/peer/peermanager.h
===================================================================
--- libktorrent/peer/peermanager.h      (revision 724887)
+++ libktorrent/peer/peermanager.h      (working copy)
@@ -131,10 +131,10 @@
                void stop();

                /**
* Kill all peers who have been choked longer then @a older_then time.
* @param older_then Time in milliseconds
                 */
-               void killChokedPeers(Uint32 older_then);
+               void killChokedPeers(Uint32 older_than);

                Uint32 getNumConnectedPeers() const {return peer_list.count();}
                Uint32 getNumPending() const {return num_pending;}
@@ -131,10 +131,10 @@

                /**
-                * Kill all peers who have been choked longer then @a older_then time.
-                * @param older_then Time in milliseconds
+                * Kill all peers who have been choked longer than @a older_than time.
+                * @param older_than Time in milliseconds
                 */